==> lessR_4.1.5.tar.gz: lessR/inst/shiny_examples/BarChart2/ui.R <==
library(shiny)

ui <- fluidPage(  # Define UI for app that draws the bar chart

  titlePanel("Bar Chart"),  # App title

  sidebarLayout(  # Sidebar layout with input and output definitions

    sidebarPanel(  # Sidebar panel for inputs

    selectInput(inputId = "myFill",
                label = "fill",
                choices = list(
                  "colors", "darkred", "gray45", "gray75", "slategray3",
                  "magenta3", "darkseagreen2", "purple",
                  "reds", "rusts", "yellows",
                  "olives", "greens", "emeralds", "turquoises",
                  "aquas", "blues", "purples", "violets",
                  "magentas", "grays")
      ),

      selectInput(inputId = "myColor",
                  label = "color",
                  choices = list("off", "darkgray", "black", "gold")
      ),

      sliderInput(inputId = "myTrans",
                  label = "trans",
                  min = 0, max = 1, value = 0
      ),

      checkboxInput(inputId = "myHoriz",
                    label = "horiz",
                    value = FALSE
      ),

      checkboxInput(inputId = "myBeside",
                    label = "beside",
                    value = FALSE
      ),

      checkboxInput(inputId = "my100",
                    label = "stack100",
                    value = FALSE
      ),

      selectInput(inputId = "myValues",
                  label = "values",
                  choices = list("%", "input", "off")
      ),

      selectInput(inputId = "myValuesColor",
                  label = "values_color",
                  choices = list("white", "gray", "darkgray", "black")
      ),

      sliderInput(inputId = "myValuesSize",
                  label = "values_size",
                  min = 0, max = 2, value = 0.9, step=0.1
      )

    ),

    mainPanel(  # Main panel for displaying outputs
      plotOutput(outputId = "myPlot")  # Output
    )

  )
)

==> lessR_4.1.7.tar.gz: lessR/inst/shiny_examples/BarChart2/ui.R <==
library(shiny)

ui <- fluidPage(  # Define UI for app that draws the bar chart

  titlePanel("Bar Chart"),  # App title

  sidebarLayout(  # Sidebar layout with input and output definitions

    sidebarPanel(  # Sidebar panel for inputs

    selectInput(inputId = "myFill",
                label = "fill",
                choices = list(
                  "colors", "darkred", "gray45", "gray75",
                  "slategray3",
                  "magenta3", "darkseagreen2", "purple",
                  "reds", "rusts", "yellows",
                  "olives", "greens", "emeralds", "turquoises",
                  "aquas", "blues", "purples", "violets",
                  "magentas", "grays")
      ),

      selectInput(inputId = "myColor",
                  label = "color",
                  choices = list("off", "darkgray", "black", "gold")
      ),

      sliderInput(inputId = "myTrans",
                  label = "trans",
                  min = 0, max = 1, value = 0
      ),

      checkboxInput(inputId = "myHoriz",
                    label = "horiz",
                    value = FALSE
      ),

      checkboxInput(inputId = "myBeside",
                    label = "beside",
                    value = FALSE
      ),

      checkboxInput(inputId = "my100",
                    label = "stack100",
                    value = FALSE
      ),

      selectInput(inputId = "myValues",
                  label = "values",
                  choices = list("%", "input", "off")
      ),

      selectInput(inputId = "myValuesColor",
                  label = "values_color",
                  choices = list("white", "gray", "darkgray", "black")
      ),

      sliderInput(inputId = "myValuesSize",
                  label = "values_size",
                  min = 0, max = 2, value = 0.9, step=0.1
      )

    ),

    mainPanel(  # Main panel for displaying outputs
      plotOutput(outputId = "myPlot")  # Output
    )

  )
)
